pub(crate) struct UserObject {
version: u8,
user_id: Id,
payload: Bytes,
object_id: Id,
}Expand description
Represents how an object stored for a user is stored in our object store
Fields
version: u8So that we can change the format in the future
user_id: IdThe user that uploaded this object
payload: BytesActual contents of the object
object_id: IdDigest of this object - not actually stored in the object itself, but cached here
Implementations