pub struct UserObjectDetails {
pub size: u32,
pub id: Id,
}Expand description
Details contained in UserState about an object stored by a user at pubhubs central
Fields
size: u32To make sure a user does not exceed their quotum
id: IdThe sha256 digest of the stored object
Implementations
Sourceimpl UserObjectDetails
impl UserObjectDetails
Sourcepub(crate) fn into_user_version(self, hmac_secret: &[u8]) -> UserObjectDetails
pub(crate) fn into_user_version(self, hmac_secret: &[u8]) -> UserObjectDetails
Turns this UserObjectDetails into a api::phc::user::UserObjectDetails.